==> haskell-contravariant-extras-0.3.3.1-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.3.1
id: contravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
key: contravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
abi: 3764f60d354d4567739ecfd6bf7be6b6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/contravariant-extras-0.3.3.1
hs-libraries: HScontravariant-extras-0.3.3.1-6AvuWK4Qahw4D6uBR5fRq7
depends:
    base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11 template-haskell-2.11.0.0
    tuple-th-0.2.5-3w3e3WQ1jmi8zIzFwGGKsB
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-extras-0.3.3.1-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-contravariant-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: contravariant-extras
version: 0.3.3.1
id: contravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
key: contravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/contravariant-extras
synopsis: Extras for the "contravariant" package
category: Control
author: Nikita Volkov <nikita.y.volkov@mail.ru>
exposed: True
exposed-modules:
    Contravariant.Extras Contravariant.Extras.Contrazip
    Contravariant.Extras.Op Contravariant.Extras.Op.Contrazip
hidden-modules: Contravariant.Extras.TH
abi: 6cc43f7aeb72d6274db0e8a49fb1b073
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/contravariant-extras-0.3.3.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/contravariant-extras-0.3.3.1
hs-libraries: HScontravariant-extras-0.3.3.1-6JwLhf1IH33AIT8qu08gpr
depends:
    base-prelude-1.2.0.1-fuY5fEKAmeDVnWLCVSGcQ
    contravariant-1.4-BhMeiKXigEF6jqFehOEdeG template-haskell-2.11.0.0
    tuple-th-0.2.5-3w3e3WQ1jmi8zIzFwGGKsB
haddock-interfaces: /usr/share/doc/haskell-contravariant-extras/html/contravariant-extras.haddock
haddock-html: /usr/share/doc/haskell-contravariant-extras/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
